==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/TimeAxisLabelFormatDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TimeAxisLabelFormatDescription } from "./TimeAxisLabelFormatDescription";
/**
 * @hidden
 */
var TimeAxisLabelFormatDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TimeAxisLabelFormatDescriptionMetadata, _super);
    function TimeAxisLabelFormatDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TimeAxisLabelFormatDescriptionMetadata.b = function (a) {
        if (TimeAxisLabelFormatDescriptionMetadata.a == null) {
            TimeAxisLabelFormatDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TimeAxisLabelFormatDescriptionMetadata.c(TimeAxisLabelFormatDescriptionMetadata.a);
        }
        if (a.g(TimeAxisLabelFormatDescriptionMetadata.a)) {
            return;
        }
        a.s(TimeAxisLabelFormatDescriptionMetadata.a);
    };
    TimeAxisLabelFormatDescriptionMetadata.c = function (a) {
        a.item("Range", "TimeSpan");
        a.item("Format", "String");
        a.item("RepeatedYearFormat", "String");
        a.item("RepeatedMonthFormat", "String");
        a.item("RepeatedDayFormat", "String");
    };
    TimeAxisLabelFormatDescriptionMetadata.d = function (a) {
        TimeAxisLabelFormatDescriptionMetadata.b(a);
        a.u("TimeAxisLabelFormat", function () { return new TimeAxisLabelFormatDescription(); });
        a.t("TimeAxisLabelFormat", TimeAxisLabelFormatDescriptionMetadata.a);
    };
    TimeAxisLabelFormatDescriptionMetadata.$t = markType(TimeAxisLabelFormatDescriptionMetadata, 'TimeAxisLabelFormatDescriptionMetadata');
    TimeAxisLabelFormatDescriptionMetadata.a = null;
    return TimeAxisLabelFormatDescriptionMetadata;
}(Base));
export { TimeAxisLabelFormatDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/TimeAxisLabelFormatDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TimeAxisLabelFormatDescription } from "./TimeAxisLabelFormatDescription";
/**
 * @hidden
 */
var TimeAxisLabelFormatDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TimeAxisLabelFormatDescriptionMetadata, _super);
    function TimeAxisLabelFormatDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TimeAxisLabelFormatDescriptionMetadata.b = function (a) {
        if (TimeAxisLabelFormatDescriptionMetadata.a == null) {
            TimeAxisLabelFormatDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TimeAxisLabelFormatDescriptionMetadata.c(TimeAxisLabelFormatDescriptionMetadata.a);
        }
        if (a.j(TimeAxisLabelFormatDescriptionMetadata.a)) {
            return;
        }
        a.y(TimeAxisLabelFormatDescriptionMetadata.a);
    };
    TimeAxisLabelFormatDescriptionMetadata.c = function (a) {
        a.item("Range", "TimeSpan");
        a.item("Format", "String");
        a.item("RepeatedYearFormat", "String");
        a.item("RepeatedMonthFormat", "String");
        a.item("RepeatedDayFormat", "String");
    };
    TimeAxisLabelFormatDescriptionMetadata.d = function (a) {
        TimeAxisLabelFormatDescriptionMetadata.b(a);
        a.aa("TimeAxisLabelFormat", function () { return new TimeAxisLabelFormatDescription(); });
        a.z("TimeAxisLabelFormat", TimeAxisLabelFormatDescriptionMetadata.a);
    };
    TimeAxisLabelFormatDescriptionMetadata.$t = markType(TimeAxisLabelFormatDescriptionMetadata, 'TimeAxisLabelFormatDescriptionMetadata');
    TimeAxisLabelFormatDescriptionMetadata.a = null;
    return TimeAxisLabelFormatDescriptionMetadata;
}(Base));
export { TimeAxisLabelFormatDescriptionMetadata };
